==> ajaxplorer-4.2.3.tbz: www/ajaxplorer/plugins/access.ajxp_conf/i18n/en.php <==
<?php
/*
 * Copyright 2007-2011 Charles du Jeu <contact (at) cdujeu.me>
 * This file is part of AjaXplorer.
 *
 * AjaXplorer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * AjaXplorer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with AjaXplorer.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The latest code can be found at <http://www.ajaxplorer.info/>.
 */
$mess=array(
"1" => "Configuration Data",
"2" => "Users",
"3" => "Repositories",
"4" => "Logs",
"5" => "Diagnostic",
"6" => "User Name",
"7" => "Is Admin", 
"8" => "Repository Label",
"9" => "Access Type",
"10" => "Meta Sources",
"11" => "Add a source",
"12" => "Meta Plugin",
"13" => "Are you sure you want to delete this source?",
"14" => "True",
"15" => "False",
"16" => "Fle Date",
"17" => "Date",
"18" => "I.P.", 
"19" => "Level",
"20" => "User", 
"21" => "Action", 
"22" => "Params",
"23" => "Test Name",
"24" => "Test Data",
"25" => "Repositories Access", 
"26" => "Modify Password",
"27" => "Admin Right",
"28" => "User has admin rights?", 
"29" => "Read", 
"30" => "Write",
"32" => "Repository Driver",
"33" => "Loading...",
"34" => "Are you sure you want to delete this user? This operation is not reversible!",
"35" => "Are you sure you want to delete this repository? This operation is not reversible!",
"36" => "Mandatory fields are missing!",
"37" => "Warning, password and confirmation differ!",
"38" => "Please fill the login field!",
"39" => "Please fill both password fields!", 
"40" => "Please check the box to confirm!",
"41" => "Driver Options",
"42" => "Please choose a driver!",
"43" => "User already exists, please choose another login!",
"44" => "User created successfully",
"45" => "Changed admin right for user ",
"46" => "Changed right for user ",
"47" => "Saved data for user ",
"48" => "Password changed successfully for user ",
"49" => "Cannot update password",
"50" => "Error: a repository with the same name already exists",
"51" => "The conf directory is not writeable",
"52" => "Successfully created repository! You can now add some 'Metadata Sources' to enrich the data, add automatic indexation, etc",
"53" => "Error while trying to edit repository", 
"54" => "Successfully edited repository", 
"55" => "Warning, at the moment, you can only add one instance of each meta plugin.", 
"56" => "Successfully added meta source", 
"57" => "Successfully deleted meta source",
"58" => "Successfully edited meta source",
"59" => "Successfully deleted repository",
"60" => "User successfully erased",
"61" => "Wrong arguments!",
"62" => "Rights Summary",
"63" => "All",
"64" => "Changed right for role ",
"65" => "Role already exists, choose another name!",
"66" => "Role successfully created",
"67" => "Cannot find role ",
"68" => "Successfully deleted role",
"69" => "Roles",
"70" => "User Roles",
"71" => "Available Roles",
"72" => "Drag'n'drop roles to assign them to the user",
"73" => "Role added to user ",
"74" => "Role deleted from user ",
"75" => "New Role",
"role_access" => "o",
"76" => "Role Id",
"77" => "Access Control", 
"78" => "Personal data",
"79" => "Repository",
"80" => "Fine-tune access for this user (Click on a repository label if you wish to make it the default repository when user logs in)",
"81" => "Specific repositories data",
"82" => "Batch-edit users",
"83" => "Drag'n'drop roles to apply them to all selected users (shared users are skipped)",
"84" => "Users Roles",
"85" => "Manual actions filtering",
"86" => "list of comma-separated actions that will be disabled for this role, no matter the access right.",
"87" => "Successfully updated actions for this role",
"88" => "This repository is defined in the config file, you cannot edit its meta sources via the GUI.",
"89" => "User specific data",
"90" => "Repository",
"91" => "Template",
"92" => "Create a new template",
"93" => "Edit",
"94" => "Batch Edit",
"95" => "Choose a label and a driver to access the data (check all sections for mandatory fields, you can hover the options labels with your mouse to get more info).",
"96" => "Once a label and driver selected, enable the fields you want to be prefilled in the template using the checkboxes. The other fields will be left to the user. You can enable some fields and leave them empty, if you still want to hide them from the user.",
"repository_access_key" => "N",
"97" => "Plugin options successfully updated",
"98" => "Core Configs",
"99" => "Plugins",
"100" => "Common '%s' plugins options",
"101" => "Name",
"102" => "Identifier",
"103" => "Description",
"104" => "Enabled",
"105" => "Automatic checks",
"106" => "Unique Identifier",
"107" => "Plugin Configurations",
"108" => "Documentation",
"109" => "Global Configurations",
"110" => "Repositories & Users",
"111" => "Logs & Other Data",
"112" => "<b>Apply this role by default</b> to all new users.",
"113" => "Role status was successfully modified",
"114" => "Default",
"115" => "Scheme",
"116" => "Template Label",
"117" => "Template Driver",
);

==> ajaxplorer-5.0.1.tbz: www/ajaxplorer/plugins/access.ajxp_conf/i18n/en.php <==
<?php
/*
 * Copyright 2007-2011 Charles du Jeu <contact (at) cdujeu.me>
 * This file is part of AjaXplorer.
 *
 * AjaXplorer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * AjaXplorer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with AjaXplorer.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The latest code can be found at <http://www.ajaxplorer.info/>.
 */
$mess=array(
"1" => "Configuration Data",
"2" => "Users & Groups",
"3" => "Workspaces",
"4" => "Logs",
"5" => "Diagnostic",
"6" => "User Name",
"7" => "Is Admin", 
"8" => "Workspace Label",
"9" => "Access Type",
"10" => "Meta Sources",
"11" => "Add a source",
"12" => "Meta Plugin",
"13" => "Are you sure you want to delete this source?",
"14" => "True",
"15" => "False",
"16" => "Fle Date",
"17" => "Date",
"18" => "I.P.", 
"19" => "Level",
"20" => "User", 
"21" => "Action", 
"22" => "Params",
"23" => "Test Name",
"24" => "Test Data",
"25" => "Workspaces Access",
"26" => "Modify Password",
"27" => "Admin Right",
"28" => "User has admin rights?", 
"29" => "Read", 
"30" => "Write",
"32" => "Access Driver",
"33" => "Loading...",
"34" => "Are you sure you want to delete this user? This operation is not reversible!",
"35" => "Are you sure you want to delete this workspace? This operation is not reversible!",
"36" => "Mandatory fields are missing!",
"37" => "Warning, password and confirmation differ!",
"38" => "Please fill the login field!",
"39" => "Please fill both password fields!", 
"40" => "Please check the box to confirm!",
"41" => "Driver Options",
"42" => "Please choose a driver!",
"43" => "User already exists, please choose another login!",
"44" => "User created successfully",
"45" => "Changed admin right for user ",
"46" => "Changed right for user ",
"47" => "Saved data for user ",
"48" => "Password changed successfully for user ",
"49" => "Cannot update password",
"50" => "Error: a workspace with the same name already exists",
"51" => "The conf directory is not writeable",
"52" => "Successfully created workspace! You can now add some 'Metadata Sources' to enrich the data, add automatic indexation, etc",
"53" => "Error while trying to edit worskpace",
"54" => "Successfully edited workspace",
"55" => "Warning, at the moment, you can only add one instance of each meta plugin.", 
"56" => "Successfully added meta source", 
"57" => "Successfully deleted meta source",
"58" => "Successfully edited meta source",
"59" => "Successfully deleted workspace",
"60" => "User successfully erased",
"61" => "Wrong arguments!",
"62" => "Rights Summary",
"63" => "All",
"64" => "Changed right for role ",
"65" => "Role already exists, choose another name!",
"66" => "Role successfully created",
"67" => "Cannot find role ",
"68" => "Successfully deleted role",
"69" => "Roles",
"70" => "User Roles",
"71" => "Available Roles",
"72" => "Drag'n'drop roles to assign them to the user",
"73" => "Role added to user ",
"74" => "Role deleted from user ",
"75" => "New Role",
"role_access" => "o",
"76" => "Role Id",
"77" => "Access Control", 
"78" => "Personal data",
"79" => "Workspace",
"80" => "Fine-tune access for this user (Click on a workspace label if you wish to make it the default workspace when user logs in)",
"81" => "Specific workspaces data",
"82" => "Batch-edit users",
"83" => "Drag'n'drop roles to apply them to all selected users (shared users are skipped)",
"84" => "Users Roles",
"85" => "Manual actions filtering",
"86" => "list of comma-separated actions that will be disabled for this role, no matter the access right.",
"87" => "Successfully updated actions for this role",
"88" => "This workspace is defined in the config file, you cannot edit its meta sources via the GUI.",
"89" => "User specific data",
"90" => "New Workspace",
"91" => "New Template",
"92" => "Create a new template",
"93" => "Edit",
"94" => "Batch Edit",
"95" => "Choose a label and a driver to access the data (check all sections for mandatory fields, you can hover the options labels with your mouse to get more info).",
"96" => "Once a label and driver selected, enable the fields you want to be prefilled in the template using the checkboxes. The other fields will be left to the user. You can enable some fields and leave them empty, if you still want to hide them from the user.",
"repository_access_key" => "N",
"97" => "Plugin options successfully updated",
"98" => "Core Configs",
"99" => "Plugins",
"100" => "Common '%s' plugins options",
"101" => "Name",
"102" => "Identifier",
"103" => "Description",
"104" => "Enabled",
"105" => "Automatic checks",
"106" => "Unique Identifier",
"107" => "Plugin Configurations",
"108" => "Documentation",
"109" => "Global Configurations",
"110" => "Workspaces & Users",
"111" => "Logs & Other Data",
"112" => "<b>Apply this role by default</b> to all new users.",
"113" => "Role status was successfully modified",
"114" => "Applies to",
"115" => "Scheme",
"116" => "Template Label",
"117" => "Template Driver",
"118" => "New group",
"group_access" => "g",
"119" => "Set user group",
);
